@@ -10,18 +10,31 @@ pub enum Arch {
     #[serde(alias = "x86")]
     X86,
 
-    #[serde(alias = "x86-64")]
+    #[serde(alias = "x86_64")]
     X86_64,
 
     #[serde(alias = "aarch64")]
     AArch64,
 }
 
+pub const fn get_target_arch() -> Option<Arch> {
+    if cfg!(target_arch = "x86") {
+        return Some(Arch::X86);
+    }
+    if cfg!(target_arch = "x86_64") {
+        return Some(Arch::X86_64);
+    }
+    if cfg!(target_arch = "aarch64") {
+        return Some(Arch::AArch64);
+    }
+    return None;
+}
+
 impl fmt::Display for Arch {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Arch::X86 => write!(f, "x86"),
-            Arch::X86_64 => write!(f, "x86-64"),
+            Arch::X86_64 => write!(f, "x86_64"),
             Arch::AArch64 => write!(f, "aarch64"),
         }
     }
