@@ -40,12 +40,20 @@ pub enum ErrorKind {
 
     JsonError,
 
+    TomlError,
+
     RegexError,
 
     InvalidDirname,
 
     GlobPatternError,
     GlobError,
+
+    // $HOME does not refer to a valid path.
+    // TODO(Shaohua): Merge to `InvalidDirname`
+    HomeDirError,
+
+    HttpError,
 }
 
 #[derive(Debug, Clone)]
@@ -126,3 +134,15 @@ impl From<string::FromUtf8Error> for Error {
         Error::from_string(ErrorKind::Utf8Error, format!("{}", err))
     }
 }
+
+impl From<reqwest::Error> for Error {
+    fn from(err: reqwest::Error) -> Self {
+        Error::from_string(ErrorKind::HttpError, format!("{}", err))
+    }
+}
+
+impl From<toml::de::Error> for Error {
+    fn from(err: toml::de::Error) -> Self {
+        Error::from_string(ErrorKind::TomlError, format!("{}", err))
+    }
+}
