@@ -5,11 +5,13 @@
 mod app_image;
 pub mod base;
 mod build;
+mod cmdline;
 pub mod config;
 mod deb;
+mod download;
 mod error;
 mod nsis;
 mod rpm;
 
-pub use build::build;
+pub use cmdline::read_cmdline;
 pub use error::Error;
